@@ -1,9 +1,9 @@
-/* Copyright 2000-2005 The Apache Software Foundation or its licensors, as
- * applicable.
- *
- * Licensed under the Apache License, Version 2.0 (the "License");
- * you may not use this file except in compliance with the License.
- * You may obtain a copy of the License at
+/* Licensed to the Apache Software Foundation (ASF) under one or more
+ * contributor license agreements.  See the NOTICE file distributed with
+ * this work for additional information regarding copyright ownership.
+ * The ASF licenses this file to You under the Apache License, Version 2.0
+ * (the "License"); you may not use this file except in compliance with
+ * the License.  You may obtain a copy of the License at
  *
  *     http://www.apache.org/licenses/LICENSE-2.0
  *
@@ -21,16 +21,13 @@
 #include "apr.h"
 #include "apr_strings.h"
 
-#if APR_HAVE_STDIO_H
-#include <stdio.h>              /* for sprintf() */
-#endif
-
 #include "mod_dav.h"
 #include "http_log.h"
 #include "http_config.h"
 #include "http_protocol.h"
 #include "http_core.h"
 
+APLOG_USE_MODULE(dav);
 
 /* ---------------------------------------------------------------
 **
@@ -55,7 +52,7 @@ DAV_DECLARE(const char *) dav_lock_get_activelock(request_rec *r,
     /* If no locks or no lock provider, there are no locks */
     if (lock == NULL || hooks == NULL) {
         /*
-        ** Since resourcediscovery is defined with (activelock)*, 
+        ** Since resourcediscovery is defined with (activelock)*,
         ** <D:activelock/> shouldn't be necessary for an empty lock.
         */
         return "";
@@ -117,8 +114,8 @@ DAV_DECLARE(const char *) dav_lock_get_activelock(request_rec *r,
             break;
         }
         dav_buffer_append(p, pbuf, "</D:lockscope>" DEBUG_CR);
-        sprintf(tmp, "<D:depth>%s</D:depth>" DEBUG_CR,
-                lock->depth == DAV_INFINITY ? "infinity" : "0");
+        apr_snprintf(tmp, sizeof(tmp), "<D:depth>%s</D:depth>" DEBUG_CR,
+                     lock->depth == DAV_INFINITY ? "infinity" : "0");
         dav_buffer_append(p, pbuf, tmp);
 
         if (lock->owner) {
@@ -129,15 +126,25 @@ DAV_DECLARE(const char *) dav_lock_get_activelock(request_rec *r,
             */
             dav_buffer_append(p, pbuf, lock->owner);
         }
-                
+
         dav_buffer_append(p, pbuf, "<D:timeout>");
         if (lock->timeout == DAV_TIMEOUT_INFINITE) {
             dav_buffer_append(p, pbuf, "Infinite");
         }
         else {
             time_t now = time(NULL);
-            sprintf(tmp, "Second-%lu", (long unsigned int)(lock->timeout - now));
-            dav_buffer_append(p, pbuf, tmp);
+            
+            /*
+            ** Check if the timeout is not, for any reason, already elapsed.
+            ** (e.g., because of a large collection, or disk under heavy load...)
+             */
+            if (now >= lock->timeout) {
+                dav_buffer_append(p, pbuf, "Second-0");
+            }
+            else {
+                apr_snprintf(tmp, sizeof(tmp), "Second-%lu", (long unsigned int)(lock->timeout - now));
+                dav_buffer_append(p, pbuf, tmp);
+            }
         }
 
         dav_buffer_append(p, pbuf,
@@ -172,7 +179,7 @@ DAV_DECLARE(dav_error *) dav_lock_parse_lockinfo(request_rec *r,
     dav_lock *lock;
 
     if (!dav_validate_root(doc, "lockinfo")) {
-        return dav_new_error(p, HTTP_BAD_REQUEST, 0,
+        return dav_new_error(p, HTTP_BAD_REQUEST, 0, 0,
                              "The request body contains an unexpected "
                              "XML root element.");
     }
@@ -187,7 +194,7 @@ DAV_DECLARE(dav_error *) dav_lock_parse_lockinfo(request_rec *r,
 
     lock->depth = dav_get_depth(r, DAV_INFINITY);
     if (lock->depth == -1) {
-        return dav_new_error(p, HTTP_BAD_REQUEST, 0,
+        return dav_new_error(p, HTTP_BAD_REQUEST, 0, 0,
                              "An invalid Depth header was specified.");
     }
     lock->timeout = dav_get_timeout(r);
@@ -223,14 +230,14 @@ DAV_DECLARE(dav_error *) dav_lock_parse_lockinfo(request_rec *r,
             ** Store a full <DAV:owner> element with namespace definitions
             ** and an xml:lang definition, if applicable.
             */
-            apr_xml_to_text(p, child, APR_XML_X2T_FULL_NS_LANG, doc->namespaces, 
+            apr_xml_to_text(p, child, APR_XML_X2T_FULL_NS_LANG, doc->namespaces,
                             NULL, &text, NULL);
             lock->owner = text;
 
             continue;
         }
 
-        return dav_new_error(p, HTTP_PRECONDITION_FAILED, 0,
+        return dav_new_error(p, HTTP_PRECONDITION_FAILED, 0, 0,
                              apr_psprintf(p,
                                          "The server cannot satisfy the "
                                          "LOCK request due to an unknown XML "
@@ -346,7 +353,7 @@ DAV_DECLARE(dav_error *) dav_add_lock(request_rec *r,
         if (multi_status != NULL) {
             /* manufacture a 207 error for the multistatus response */
             *response = multi_status;
-            return dav_new_error(r->pool, HTTP_MULTI_STATUS, 0,
+            return dav_new_error(r->pool, HTTP_MULTI_STATUS, 0, 0,
                                  "Error(s) occurred on resources during the "
                                  "addition of a depth lock.");
         }
@@ -359,7 +366,7 @@ DAV_DECLARE(dav_error *) dav_add_lock(request_rec *r,
 ** dav_lock_query:  Opens the lock database. Returns a linked list of
 **    dav_lock structures for all direct locks on path.
 */
-DAV_DECLARE(dav_error*) dav_lock_query(dav_lockdb *lockdb, 
+DAV_DECLARE(dav_error*) dav_lock_query(dav_lockdb *lockdb,
                                        const dav_resource *resource,
                                        dav_lock **locks)
 {
@@ -450,7 +457,7 @@ static dav_error * dav_get_direct_resource(apr_pool_t *p,
 
         /* not found! that's an error. */
         if (lock == NULL) {
-            return dav_new_error(p, HTTP_BAD_REQUEST, 0,
+            return dav_new_error(p, HTTP_BAD_REQUEST, 0, 0,
                                  "The specified locktoken does not correspond "
                                  "to an existing lock on this resource.");
         }
@@ -471,7 +478,7 @@ static dav_error * dav_get_direct_resource(apr_pool_t *p,
         resource = parent;
     }
 
-    return dav_new_error(p, HTTP_INTERNAL_SERVER_ERROR, 0,
+    return dav_new_error(p, HTTP_INTERNAL_SERVER_ERROR, 0, 0,
                          "The lock database is corrupt. A direct lock could "
                          "not be found for the corresponding indirect lock "
                          "on this resource.");
@@ -507,7 +514,7 @@ DAV_DECLARE(int) dav_unlock(request_rec *r, const dav_resource *resource,
     /* 2518 requires the entire lock to be removed if resource/locktoken
      * point to an indirect lock.  We need resource of the _direct_
      * lock in order to walk down the tree and remove the locks.  So,
-     * If locktoken != null_locktoken, 
+     * If locktoken != null_locktoken,
      *    Walk up the resource hierarchy until we see a direct lock.
      *    Or, we could get the direct lock's db/key, pick out the URL
      *    and do a subrequest.  I think walking up is faster and will work
@@ -600,7 +607,7 @@ static dav_error * dav_inherit_locks(request_rec *r, dav_lockdb *lockdb,
         }
         if (parent == NULL) {
             /* ### map result to something nice; log an error */
-            return dav_new_error(r->pool, HTTP_INTERNAL_SERVER_ERROR, 0,
+            return dav_new_error(r->pool, HTTP_INTERNAL_SERVER_ERROR, 0, 0,
                                  "Could not fetch parent resource. Unable to "
                                  "inherit locks from the parent and apply "
                                  "them to this resource.");
@@ -711,7 +718,7 @@ DAV_DECLARE(int) dav_get_resource_state(request_rec *r,
         if (r->path_info != NULL && *r->path_info != '\0') {
             return DAV_RESOURCE_NULL;
         }
-        
+
         if ((err = (*hooks->open_lockdb)(r, 1, 1, &lockdb)) == NULL) {
             /* note that we might see some expired locks... *shrug* */
             err = (*hooks->has_locks)(lockdb, resource, &locks_present);
@@ -721,7 +728,7 @@ DAV_DECLARE(int) dav_get_resource_state(request_rec *r,
         if (err != NULL) {
             /* ### don't log an error. return err. add higher-level desc. */
 
-            ap_log_rerror(APLOG_MARK, APLOG_ERR, 0, r,
+            ap_log_rerror(APLOG_MARK, APLOG_ERR, 0, r, APLOGNO(00623)
                           "Failed to query lock-null status for %s",
                           r->filename);
 
