@@ -112,6 +112,8 @@ md_t *md_create_empty(apr_pool_t *p)
         md->transitive = -1;
         md->acme_tls_1_domains = apr_array_make(p, 5, sizeof(const char *));
         md->stapling = -1;
+        md->profile_mandatory = -1;
+        md->ari_renewals = -1;
         md->defn_name = "unknown";
         md->defn_line_number = 0;
     }
@@ -319,6 +321,7 @@ md_json_t *md_to_json(const md_t *md, apr_pool_t *p)
         }
         if (md->profile) md_json_sets(md->profile, json, MD_KEY_PROFILE, NULL);
         md_json_setb(md->profile_mandatory > 0, json, MD_KEY_PROFILE_MANDATORY, NULL);
+        md_json_setb(md->ari_renewals > 0, json, MD_KEY_ARI_RENEWALS, NULL);
         return json;
     }
     return NULL;
@@ -389,6 +392,7 @@ md_t *md_from_json(md_json_t *json, apr_pool_t *p)
         md->profile_mandatory = (int)md_json_getb(json, MD_KEY_PROFILE_MANDATORY, NULL);
         if (md_json_has_key(json, MD_KEY_PROFILE, NULL))
             md->profile = md_json_dups(p, json, MD_KEY_PROFILE, NULL);
+        md->ari_renewals = (int)md_json_getb(json, MD_KEY_ARI_RENEWALS, NULL);
         return md;
     }
     return NULL;
@@ -426,7 +430,7 @@ const char *md_get_ca_name_from_url(apr_pool_t *p, const char *url)
     unsigned int i;
 
     for (i = 0; i < sizeof(KNOWN_CAs)/sizeof(KNOWN_CAs[0]); ++i) {
-        if (!apr_strnatcasecmp(KNOWN_CAs[i].url, url)) {
+        if (!apr_cstr_casecmp(KNOWN_CAs[i].url, url)) {
             return KNOWN_CAs[i].name;
         }
     }
@@ -444,7 +448,7 @@ apr_status_t md_get_ca_url_from_name(const char **purl, apr_pool_t *p, const cha
 
     *purl = NULL;
     for (i = 0; i < sizeof(KNOWN_CAs)/sizeof(KNOWN_CAs[0]); ++i) {
-        if (!apr_strnatcasecmp(KNOWN_CAs[i].name, name)) {
+        if (!apr_cstr_casecmp(KNOWN_CAs[i].name, name)) {
             *purl = KNOWN_CAs[i].url;
             goto leave;
         }
